
# GUI Executor

You ever wanted to execute your Python code from a simple GUI without the need to use a REPL or commandline? Look no further, use GUI Executor.


## Installation

Install this package in your virtual environment:

```
python3 -m pip install gui-executor 
```
